@@ -2,7 +2,7 @@ package Perl6::Doc;
 use 5.000;
 use File::Spec;
 
-$Perl6::Doc::VERSION = '0.33';
+$Perl6::Doc::VERSION = '0.34';
 
 sub new {
     my $class = shift;
@@ -64,7 +64,7 @@ sub get_raw {
       or die "Missing argument for get_raw";
     my $document = $self->normalize_name($id);
     $document .= '.pod';
-    $document = File::Spec->catfile('Perl6', 'Doc', 'Bible', $document);
+    $document = File::Spec->catfile('Perl6', 'Doc', 'Design', $document);
     my $document_path = '';
     for my $path (@INC) {
         my $file_path = File::Spec->catfile($path, $document);
@@ -85,20 +85,36 @@ sub perldoc {
     my $args = shift;
     my $document = __PACKAGE__ ;
     if (@_){
-        my $file_name = $self->normalize_name( shift );
-        if ($file_name eq 'T01' or $file_name eq 'Perlintro'){
-            $document .= '::Tutorial::perlintro';
-        } elsif ($file_name eq 'F01') { $document .= '::Doc::Capture';
-        } elsif ($file_name eq 'F02') { $document .= '::Doc::FUD';
-        } elsif ($file_name eq 'O03') { $document .= '::Doc::Operator';
-        } elsif ($file_name eq 'O04') { $document .= '::Doc::Smartmatch';
-        } elsif ($file_name eq 'O06') { $document .= '::Doc::Subroutine';
-        } elsif ($file_name eq 'O08') { $document .= '::Doc::Variable';
-        } elsif ($file_name eq 'O09') { $document .= '::Doc::Data';
-        } elsif ($file_name eq 'O12') { $document .= '::Doc::Object';
-        } elsif ($file_name eq 'O16') { $document .= '::Doc::File';
+        my $file = $self->normalize_name( shift );
+        my $sigil = substr $file, 0, 1;
+        if ($file eq 'Perlintro'){
+            $document .= '::Docs::Tutorial::perlintro';
+        } elsif ($sigil eq 'T'){
+            $document .= '::Docs::Tutorial::';
+            if ($file eq 'T01') { $document .= 'perlintro' }
+            else                { $self->contents, return  }
+        } elsif ($file eq 'F01') { $document .= '::Doc::Capture';
+        } elsif ($file eq 'F02') { $document .= '::Doc::FUD';
+        } elsif ($sigil eq 'O') {
+            $document .= '::';
+            if    ($file eq 'O03') { $document .= 'Operator'  }
+            elsif ($file eq 'O04') { $document .= 'Smartmatch'}
+            elsif ($file eq 'O06') { $document .= 'Subroutine'}
+            elsif ($file eq 'O08') { $document .= 'Variable'  }
+            elsif ($file eq 'O09') { $document .= 'Data'      }
+            elsif ($file eq 'O12') { $document .= 'Object'    }
+            elsif ($file eq 'O16') { $document .= 'File'      } 
+            else                   { $self->contents, return }
+        } elsif ($sigil eq 'M') {
+            $document .= '::Magazine::';
+            if    ($file eq 'M01') { $document .= 'perl-6-announcement'}
+            elsif ($file eq 'M02') { $document .= 'what-is-perl-6'}
+            elsif ($file eq 'M03') { $document .= 'pugs-interview'}
+            elsif ($file eq 'M04') { $document .= 'everyday-perl-6'}
+            elsif ($file eq 'M05') { $document .= 'perl-6-parameter-passing'}
+            else                   { $self->contents, return }
         } else {
-            $document .= '::Bible::' . $file_name;
+            $document .= '::Design::' . $file;
         }
     }
     my $options = join ' ', grep { defined $args->{$_} } qw(-t -u -m -T);
@@ -120,15 +136,16 @@ sub help {
     print <<_;
 
 Usage: p6doc [options] [document-id]
-View the Perl 6 Canon.
 
 Possible values for document-id are:
-  A01 - A33  (Perl 6 Apocalypses)
-  E01 - E33  (Perl 6 Exegeses)
-  S01 - S33  (Perl 6 Synopses)
-  F01 - F33  (Perl 6 FAQ)
-  O01 - O33  (Perl 6 Overview)
+  A01 - A20  (Perl 6 Apocalypses)
+  E02 - E07  (Perl 6 Exegeses)
+  S01 - S29  (Perl 6 Synopses)
+  O01 - O16  (Perl 6 Overview)
+  F01 - F02  (Perl 6 FAQ)
   T01        (Perl 6 Tutorial)
+  P00 - P09  (Perl(6)Tables)
+  M01 - M05  (Mazine Articles)
 
 Valid options:
   -h,  --help       Print this help screen
@@ -141,7 +158,7 @@ _
 
 sub version {
     print <<_;
-This is Perl 6 Documentation as of December 24, 2007
+This is Perl 6 Documentation as of January 1, 2008
 (bundled in Perl6-Doc-$VERSION)
 _
 }
@@ -192,7 +209,7 @@ This Perl module distribution contains all the latest Perl 6
 documentation and a utility called C<p6doc> for viewing it.
 
 Below is the list of documents that are currently available; a number
-in the column indicates the document is currently available. An
+in the column indicates the document is currently available. An 
 asterisk next to a number means that the document is an unofficial
 draft written by a member of the Perl community but not approved by
 the Perl 6 Design Team.
@@ -216,7 +233,7 @@ the Perl 6 Design Team.
          Debugging                         (A20*)
     S22* CPAN
          Portable Perl
-    S26* Perl Documentation
+    S26  Perl Documentation
     S27* Perl Culture
     S28* Special Names
     S29* Functions
@@ -234,6 +251,12 @@ the Perl 6 Design Team.
     
     T01  Tutorial perlintro
 
+    M01  Report on the Perl 6 Announcement
+    M02  What is Perl 6 ?
+    M03  A Plan for Pugs
+    M04  Everyday Perl 6
+    M05  The Beauty of Perl 6 Parameter Passing
+
 =head1 NOTES
 
 L<Perl6::Doc> was before L<Perl6::Bible> which is now depreciated. We
@@ -250,7 +273,7 @@ The document codes C<S01 - S33> refer to the Perl 6 Synopses.
 
 The Synopsis documents are to be taken as the formal specification for
 Perl 6 implementations, while still being reference documentation for
-Perl 6, like _Programming Perl_ is for Perl 5.
+Perl 6, like I<Programming Perl> is for Perl 5.
 
 Note that while these documents are considered "formal specifications",
 they are still being subjected to the rigours of cross-examination
@@ -261,12 +284,12 @@ expectation is that they are "very close" to the final shape of Perl 6.
 
 =head2 Apocalypses (outdated)
 
-The document codes C<A01 - A33> refer to the Perl 6 Apocalypses.
+The document codes C<A01 - A20> refer to the Perl 6 Apocalypses.
 
 Larry Wall started the Apocalypse series as a systematic way of
 answering the RFCs (Request For Comments) that started the design
 process for Perl 6.  Each Apocalypse corresponds to a chapter in the
-book _Programming Perl_, 3rd edition, and addresses the features
+book I<Programming Perl>, 3rd edition, and addresses the features
 relating to that chapter in the book that are likely to change.
 
 Larry addresses each relevant RFC, and gives reasons why he accepted
@@ -276,7 +299,7 @@ problems identified in the RFCs.
 
 =head2 Exegeses (outdated)
 
-The document codes C<E01 - E33> refer to the Perl 6 Exegeses.
+The document codes C<E02 - E07> refer to the Perl 6 Exegeses.
 
 Damian Conway's Exegeses are extensions of each Apocalypse.  Each
 Exegesis is built around a practical code example that applies and
@@ -290,8 +313,19 @@ outdated Synopses that are still marked as [Draft].
 
 =head2 Tutorial (building up)
 
-This is an community driven effort to translate the Perl 5 manpages into
-the shiny Perl 6 world. There are still are half way through the intro.
+This is an community driven effort to translate the Perl 5 manpages
+into the shiny Perl 6 world. There are still are half way through the
+intro.
+
+=head2 Perl Tables
+
+Reference styled set of wiki pages made by myself.
+
+=head2 Magazine articles
+
+Helpful articles from perl.com (L<http://www.perl.com>) and $foo
+(L<http://www.perl-magazin.de/>). See the authors name in the 
+section L</SCRIBES>, right below.
 
 =head1 METHODS
 
@@ -301,23 +335,34 @@ Perl6::Doc provides a class method to get the raw text of a document:
 
 =head1 SCRIBES
 
+These are the authors of the included docs, named in the order their work 
+was added :
+
 * Ingy dt Net <ingy@cpan.org>
 
 * Sam Vilain <samv@cpan.org>
 
 * Audrey Tang <autrijus@cpan.org>
 
-* Herbert Breunung <lichtkind@cpan.org>
-
 * Kirrily "Skud" Robert <skud@cpan.org>
 
 * Moritz Lenz <moritz@fau2ik3.org>
 
 * David Koenig <karhu@u.washington.edu>
 
+* Jonathan Scott Duff <duff@pobox.com>
+
+* Phil Crow <philcrow2000@yahoo.com>
+
+* chromatic <chromatic@oreilly.com>
+
+* Mark-Jason Dominus <mjd@songline.com>
+
+* Herbert Breunung <lichtkind@cpan.org>
+
 =head1 SOURCES
 
-A couple of paragraphs from _Perl 6 Essentials_ were used for the
+A couple of paragraphs from I<Perl 6 Essentials> were used for the
 overview. Most of the Bible docs (Apocalypses, Exegeses, Synopses)
 are from the official Perl development site. 
 
